#ifndef NT2_INCLUDE_FUNCTIONS_IROUND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IROUND_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/iround.hpp>

#endif
